Relay Commander
===============

A CLI for managing `LaunchDarkly Relay <https://github.com/launchdarkly/ld-relay>`__ Instances.

.. image:: https://codecov.io/gh/launchdarkly/relayCommander/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/launchdarkly/relayCommander

.. image:: https://circleci.com/gh/launchdarkly/relayCommander.svg?style=shield
    :target: https://circleci.com/gh/launchdarkly/relayCommander

.. image:: https://readthedocs.org/projects/relay-commander/badge/?version=latest
    :target: http://relaycommander.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://badge.fury.io/py/relaycommander.svg
    :target: https://badge.fury.io/py/relaycommander

Installation
============

::

    pip install relaycommander

Contributing
============

Please create an issue with a description of your problem, or open a pull request with a fix.

License
=======

Apache 2.0
